@@ -16,7 +16,7 @@ import argparse
 import pytest
 
 import fsl
-from fsl.utils         import fslsub
+from fsl.utils         import fslsub, run
 from fsl.utils.tempdir import tempdir
 
 from . import mockFSLDIR
@@ -256,3 +256,44 @@ def test_info():
 
     with pytest.raises(ValueError):
         fslsub._parse_qstat(valid_job_ids[0], example_qstat_reply)
+
+
+def _good_func():
+    print('hello')
+
+
+def _bad_func():
+    1/0
+
+
+def test_func_to_cmd():
+    cwd = os.getcwd()
+    with tempdir():
+        for tmp_dir in (None, '.'):
+            for clean in ('never', 'on_success', 'always'):
+                for verbose in (False, True):
+                    cmd = fslsub.func_to_cmd(_good_func, clean=clean, tmp_dir=tmp_dir, verbose=verbose)
+                    fn = cmd.split()[-1]
+                    assert op.exists(fn)
+                    stdout, stderr, exitcode = run.run(cmd, exitcode=True, stdout=True, stderr=True,
+                                                       env={"PYTHONPATH": cwd})
+                    assert exitcode == 0
+                    if clean == 'never':
+                        assert op.exists(fn), "Successful job got removed, even though this was not requested"
+                    else:
+                        assert not op.exists(fn), f"Successful job did not get removed after run for clean = {clean}"
+                    if verbose:
+                        assert stdout.strip() == f'running {fn}\nhello'
+                    else:
+                        assert stdout.strip() == 'hello'
+
+                cmd = fslsub.func_to_cmd(_bad_func, clean=clean, tmp_dir=tmp_dir)
+                fn = cmd.split()[-1]
+                assert op.exists(fn)
+                stdout, stderr, exitcode = run.run(cmd, exitcode=True, stdout=True, stderr=True,
+                                                   env={'PYTHONPATH': cwd})
+                assert exitcode != 0
+                if clean == 'always':
+                    assert not op.exists(fn), "Failing job should always be removed if requested"
+                else:
+                    assert op.exists(fn), f"Failing job got removed even with clean = {clean}"
